@@ -653,12 +653,12 @@ def update_app_utils(appname, branch, keys=False, reboot=False):
     cmd = "mkdir -p " + UPLOAD_CODE_PATH + "/" + APP_UTILS_DIR
     run(cmd)
     with cd('%s' % UPLOAD_CODE_PATH):
-        put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=True)
+        put('%s.tar.gz' % TAR_NAME, '%s.tar.gz' % TAR_NAME, use_sudo=False)
         run('tar zxf %s.tar.gz -C %s' % (TAR_NAME, APP_UTILS_DIR))
 
     # run the "instanceType"-command.sh in the appropriate branch
     cmdToRun = "$HOME/" + appname + "/" + APP_UTILS_DIR + "/config/" + ENVIRONMENT + "/${dc_TAG_Type}-commands.sh"
-    sudo(cmdToRun)
+    run(cmdToRun)
 
     # run deployenv on the instance to get the new values into /etc/enviornmnet
     run("deployenv.sh --type instance -a " + appname + " -e " + ENVIRONMENT)
